==> hexo-theme-solitude-1.8.0.tgz: package/README_en.md <==
[简体中文](README.md)丨[繁体中文](README_zh-tw.md)丨English

<div align="center">

   <img src=".github/logo.svg" alt="Solitude logo" height="200">

   <h1>Hexo Theme Solitude</h1>

   An elegant Hexo theme that supports lazy loading, PWA, Latex, and multiple comment systems.

   Theme is fully licensed and designed by the author of [@张洪Heo](https://github.com/zhheo)!
  
![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?color=blue&logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![GitHub all releases](https://img.shields.io/github/downloads/valor-x/hexo-theme-solitude/total)](https://github.com/valor-x/hexo-theme-solitude/releases/latest)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/@efu__oo-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/efuome-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[Preview](https://efu.me/) 丨  [Documentation](https://solitude-docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## Features

- Pjax、LazyLoad、PWA
- Comments(Twikoo、Waline、Valine、Artalk), Can double comment
- ColorMode
- Lightbox(medium-zoom、fancybox)
- Mathematical formulas(Latex)
- Featured pages: Instant Short Article, My Equipment, Online Tools, Music Gallery, Friend Chain Fish Pond, Photo Album Page, Douban Page
- Article features: AI summary, code highlighting

## Todo

- [x] Support Waline
- [ ] Tags plugin
- [ ] Album reconstruction(Removed, to be refactored)

## Setup

1. Use the NPM package
      ```bash
      npm i hexo-theme-solitude
      ```
2. Apply
      ```yaml
      theme: solitude
      ```

Check out the [Documentation](https://solitude-docs.efu.me/) for more information.

## Sponsors

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## License

[MIT](./LICENSE) License &copy; 2023-PRESENT [Efu](https://github.com/efuo)

==> hexo-theme-solitude-1.8.5.tgz: package/README_en.md <==
[简体中文](README.md)丨[繁体中文](README_zh-tw.md)丨English

<div align="center">

   <img src=".github/logo.svg" alt="Solitude logo" height="200">

   <h1>Hexo Theme Solitude</h1>

   An elegant Hexo theme that supports lazy loading, PWA, Latex, and multiple comment systems.

   Theme is fully licensed and designed by the author of [@张洪Heo](https://github.com/zhheo)!
  
![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?color=blue&logo=npm)
![release](https://img.shields.io/github/package-json/v/valor-x/hexo-theme-solitude/master?color=%231ab1ad&label=release)
![license](https://img.shields.io/github/license/valor-x/hexo-theme-solitude?color=FF5531)
[![Stars](https://img.shields.io/github/stars/valor-x/hexo-theme-solitude)](https://github.com/valor-x/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white)
![node version](https://img.shields.io/badge/node-14.0.0-white?logo=node.js&logoColor=white)

![Latex](https://img.shields.io/badge/latex-20B2AA?logo=Latex)
![Ads](https://img.shields.io/badge/Google_Ads-black?logo=googleads)
![algolia](https://img.shields.io/badge/algolia-457AFF?logo=algolia)

![cdnjs](https://img.shields.io/badge/cdnjs-orange?logo=Cloudflare&logoColor=white)
![A11y](https://img.shields.io/badge/A11y-green?logo=%C3%8Ele-de-France%20Mobilit%C3%A9s&logoColor=white)
![mermaid](https://img.shields.io/badge/mermaid-ff3670?logo=mermaid&logoColor=white)
[![pwa](https://img.shields.io/badge/pwa-red?logo=pwa)](https://developer.mozilla.org/en-US/docs/Web/Progressive_web_apps)

[![twiter](https://img.shields.io/badge/Twitter-gray?logo=x)](https://twitter.com/efu_oo)
[![TG](https://img.shields.io/badge/Telegram-gray?logo=Telegram&logoColor=white)](https://t.me/solitudePro)
[![Discord](https://img.shields.io/discord/1218118131428495430?label=Discord&logo=Discord&labelColor=white&color=black)](https://discord.gg/Y8VEvVgW)

![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains)
![DuoLingo](https://img.shields.io/badge/duolingo-support-black?logo=duolingo&logoColor=white)

[![gitee](https://img.shields.io/badge/Gitee-red?logo=gitee)](https://gitee.com/nsjjd_w/hexo-theme-solitude)
[![gitlab](https://img.shields.io/badge/GitLab-blue?logo=gitlab)](https://gitlab.com/efu/hexo-theme-solitude)

[Preview](https://efu.me/) 丨  [Documentation](https://solitude-docs.efu.me/)

</div>

![Screenshot](.github/screenshot.png)

## Features

- Pjax、LazyLoad、PWA
- Comments(Twikoo、Waline、Valine、Artalk), Can double comment
- ColorMode
- Lightbox(medium-zoom、fancybox)
- Mathematical formulas(Latex)
- Featured pages: Instant Short Article, My Equipment, Online Tools, Music Gallery, Friend Chain Fish Pond, Photo Album Page, Douban Page
- Article features: AI summary, code highlighting

## Todo

- [x] Artalk
- [x] Use double comment
- [x] Album

> If you have any questions, please issue an [issue](https://github.com/valor-x/hexo-theme-solitude/issues)

## Setup

1. Use the NPM package
      ```bash
      npm i hexo-theme-solitude
      ```
2. Apply
      ```yaml
      theme: solitude
      ```

Check out the [Documentation](https://solitude-docs.efu.me/) for more information.

## Sponsors

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg'/>
  </a>
</p>

## License

[MIT](./LICENSE) License &copy; 2023-PRESENT [Efu](https://github.com/efuo)
